==> jaffm-1.2.1.tar.bz2: jaffm-1.2.1/filetree.h <==
#ifndef FILETREE_H
#define FILETREE_H
#include <wx/wx.h>
#include <wx/treectrl.h>
#include <wx/image.h>
#include <wx/dir.h>
#include <wx/file.h>
#include <vector>

#include "filehandler.h"
#include "settings.h"
#include "timemonitor.h"
#include "mainwindow.h"

class MainWindow;
class UThread;

class UFiletree : public wxTreeCtrl
{
public:
	UFiletree(wxWindow *oParent, wxWindowID iID, wxTextCtrl *oLocation, MainWindow *oParentWindow, Settings *oNewSettings);
	
	wxString getFullpath(wxTreeItemId iItem);
	void selectPrevItem();
	void selectNextItem();
	wxTreeItemId getNextID(const wxTreeItemId &iItem);
	wxTreeItemId getPrevID(const wxTreeItemId &iItem);
	void ReloadDir(wxTreeItemId iItemID, const wxString &sDir, bool bCheckOnly);
	wxTreeItemId addItem(wxTreeItemId iDirID, const wxString &sItem);
	void SetRoot(const wxString &sDir, bool bSkipLocationText);
	void Activate(wxTreeItemId iItemID);
	void Activate(wxString sItem);
	bool addFile();
	bool addFolder();
	bool Rename(wxTreeItemId iItemID, const wxString &sNewName);
	bool deleteItem();
	void GoUp();
	void rightPress();
	void leftPress();
	//void checkChanges(); // Moved to UThread
	void selectTreeItem(wxTreeItemId iItem);
	void pressHome();
	void pressEnd();
	void openWith();
	void edit();
	bool somethingSelected();
	bool itemExists(const wxTreeItemId &iItem);
	bool itemExists(const wxString &sItem);
	void fixSelection();
	wxTreeItemId getTreeSelection();

	void createThread();
	
	bool bSeeHidden;
	wxString sSelectedItem;
	
	Settings *oSettings;
	UTimeMonitor oTimeMonitor;
	
private:
	MainWindow *oParentFrame;
	wxTextCtrl *txtLocation;
	
	wxTreeItemId iMovingID;
	
	wxString sTempItemLabel;

	UThread *oThread;
	
	void OnDragBegin(wxTreeEvent &oEvent);
	void OnDragEnd(wxTreeEvent &oEvent);
	void OnItemExpanding(wxTreeEvent &oEvent);
	void OnItemCollapsed(wxTreeEvent &oEvent);
	void OnItemActivated(wxTreeEvent &oEvent);
	void OnRightClick(wxTreeEvent &oEvent);
	void OnItemBeginRename(wxTreeEvent &oEvent);
	void OnItemEndRename(wxTreeEvent &oEvent);
	void OnSelChanged(wxFocusEvent &oEvent);

	void run(const wxString &sCommand, bool bTerminal);
	
	DECLARE_EVENT_TABLE()
};

#endif

==> jaffm-1.3.tar.bz2: jaffm-1.3/filetree.h <==
#ifndef FILETREE_H
#define FILETREE_H
#include <wx/wx.h>
#include <wx/treectrl.h>
#include <wx/image.h>
#include <wx/dir.h>
#include <wx/file.h>
#include <vector>

#include "filehandler.h"
#include "settings.h"
#include "timemonitor.h"
#include "mainwindow.h"
#include "dropsource.h"

class MainWindow;
class UThread;

class UFiletree : public wxTreeCtrl
{
public:
	UFiletree(wxWindow *oParent, wxWindowID iID, wxTextCtrl *oLocation, MainWindow *oParentWindow, Settings *oNewSettings);
	
	void dropFiles(std::vector<wxString> sFiles, wxCoord oX, wxCoord oY);
	wxString getFullpath(wxTreeItemId iItem);
	void selectPrevItem();
	void selectNextItem();
	wxTreeItemId getNextID(const wxTreeItemId &iItem);
	wxTreeItemId getPrevID(const wxTreeItemId &iItem);
	void ReloadDir(wxTreeItemId iItemID,bool bCheckOnly);
	wxTreeItemId addItem(wxTreeItemId iDirID, const wxString &sItem);
	void SetRoot(const wxString &sDir, bool bSkipLocationText);
	void Activate(wxTreeItemId iItemID);
	void Activate(wxString sItem);
	bool addFile();
	bool addFolder();
	bool Rename(wxTreeItemId iItemID, const wxString &sNewName);
	bool deleteItem();
	void GoUp();
	void rightPress();
	void leftPress();
	void selectTreeItem(wxTreeItemId iItem);
	void pressHome();
	void pressEnd();
	void openWith();
	void edit();
	bool somethingSelected();
	bool itemExists(const wxTreeItemId &iItem);
	bool itemExists(const wxString &sItem);
	void fixSelection();
	wxTreeItemId getSingleTreeSelection();
	std::vector<wxTreeItemId> getTreeSelections();
	
	void createThread();
	
	bool bSeeHidden;
	wxString sSelectedItem;
	
	Settings *oSettings;
	UTimeMonitor oTimeMonitor;
	
private:
	MainWindow *oParentFrame;
	UDropSource *oDropSource;
	wxTextCtrl *txtLocation;
	wxTreeItemId iMovingID;
	wxString sTempItemLabel;
	UThread *oThread;
	
	void OnDragBegin(wxTreeEvent &oEvent);
	void OnDragEnd(wxTreeEvent &oEvent);
	void OnItemExpanding(wxTreeEvent &oEvent);
	void OnItemCollapsed(wxTreeEvent &oEvent);
	void OnItemActivated(wxTreeEvent &oEvent);
	void OnRightClick(wxTreeEvent &oEvent);
	void OnItemBeginRename(wxTreeEvent &oEvent);
	void OnItemEndRename(wxTreeEvent &oEvent);
	void OnSelChanged(wxFocusEvent &oEvent);

	void OnLeaveWindow(wxMouseEvent &oEvent);

	void run(const wxString &sCommand, bool bTerminal);
	
	DECLARE_EVENT_TABLE()
};

#endif
